function param = lmsParams(alpha, beta, name)
%LMSPARAMS create parameters for lms.  PARAM = LMSPARAMS(ALPHA, BETA) or
% LMSPARAMS(ALPHA, BETA, NAME) creates parameter structure for use with lms.
% See help for LMS.

% created by Claude Gittelson

if(nargin <= 1)
    return;
end

% alpha and beta need to be column vectors
[m,n] = size(alpha);
if(m<n)
    alpha = alpha';
end
[m,n] = size(beta);
if(m<n)
    beta = beta';
end

% alpha and beta need the same length
lengthAlpha = length(alpha);
lengthBeta = length(beta);
k = max(lengthAlpha, lengthBeta);
if(lengthAlpha < k)
    temp = alpha;
    alpha = zeros(k,1);
    alpha(1:lengthAlpha) = temp;
end
if(lengthBeta < k)
    temp = beta;
    beta = zeros(k,1);
    beta(1:lengthBeta) = temp;
end

% create parameter structure
param.k = k-1; % param.k-step method
param.alpha = alpha;
param.beta = beta;
param.explicit = (param.beta(1)==0); % explicit method
param.name = '';
if(nargin>=3)
    if(ischar(name))
        param.name = name;
    end
end

% implementation of lms solver
param.solver = @lms;
