function [y, fcalls] = rkPartStep(param, ode, h, tol, y1, t, k, fcalls)
%RKPARTSTEP step of composition of rk methods

% created by Claude Gittelson

n = floor(0.5*ode.dim);
e1 = zeros(1,ode.dim);
for i=1:n
    e1(i) = 1;
end
E1 = diag(e1);
E2 = eye(ode.dim) - E1;

% newton iteration
m = 1;
conv = ones(1,param.s);
while norm(conv) > 0 & m < 100
    for i = 1:param.s
        if conv(i)
            constT = t - h + h*param.mtd1.c(i);
            constY = y1 + h*E1*k*(param.mtd1.A(i,:)') + h*E2*k*(param.mtd2.A(i,:)');
            g = k(:,i) - feval(ode.f, constT, constY, ode.fargs{:});
            Dg = eye(ode.dim) - h*(param.mtd1.A(i,i)*E1 + param.mtd2.A(i,i)*E2)*feval(ode.Df, constT, constY, ode.fargs{:});
            d = -Dg\g;
            k(:,i) = k(:,i) + d;
            if norm(d) < tol
                conv(i) = 0;
            end
            fcalls = fcalls + ode.dim + ode.dim^2;
        end
    end
end
y = y1 + h*(E1*k*param.mtd1.b + E2*k*param.mtd2.b);
